mod add;
pub use add::*;
mod ceil;
pub use ceil::*;
#[doc(hidden)]
pub fn divide() {
    todo!()
}
#[doc(hidden)]
pub fn floor() {
    todo!()
}
#[doc(hidden)]
pub fn max() {
    todo!()
}
#[doc(hidden)]
pub fn max_by() {
    todo!()
}
#[doc(hidden)]
pub use max_by as maxBy;
#[doc(hidden)]
pub fn mean() {
    todo!()
}
#[doc(hidden)]
pub fn mean_by() {
    todo!()
}
#[doc(hidden)]
pub use mean_by as meanBy;
#[doc(hidden)]
pub fn min() {
    todo!()
}
#[doc(hidden)]
pub fn min_by() {
    todo!()
}
#[doc(hidden)]
pub use min_by as minBy;
#[doc(hidden)]
pub fn multiply() {
    todo!()
}
#[doc(hidden)]
pub fn round() {
    todo!()
}
#[doc(hidden)]
pub fn subtract() {
    todo!()
}
#[doc(hidden)]
pub fn sum() {
    todo!()
}
#[doc(hidden)]
pub fn sum_by() {
    todo!()
}
#[doc(hidden)]
pub use sum_by as sumBy;
